@@ -3,18 +3,20 @@
 use strict;
 use warnings;
 
+our $VERSION = '0.0203';
+
 use lib qw(../lib lib);
 use WWW::CPANRatings::RSS;
 
 my $rate = WWW::CPANRatings::RSS->new;
 
-$rate->fetch
-    or die $rate->error;
+# $rate->fetch
+#     or die $rate->error;
 
-for ( @{ $rate->ratings } ) {
-    printf "%s - %s stars - by %s\n--- %s ---\nsee %s\n\n\n",
-        @$_{ qw/dist rating creator comment link/ };
-}
+#for ( @{ $rate->ratings } ) {
+#    printf "%s - %s stars - by %s\n--- %s ---\nsee %s\n\n\n",
+#        @$_{ qw/dist rating creator comment link/ };
+#}
 
 print "\n\n\nNew reviews:\n";
 
@@ -24,4 +26,4 @@ $rate->fetch_unique
 for ( @{ $rate->ratings_unique } ) {
     printf "%s - %s stars - by %s\n--- %s ---\nsee %s\n\n\n",
         @$_{ qw/dist rating creator comment link/ };
-}
\ No newline at end of file
+}
